#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.12
visibility:           public
id:                   crypton-x509-store-1.6.12-KkyYkb9jfDzGqLhKg6ml0O
key:                  crypton-x509-store-1.6.12-KkyYkb9jfDzGqLhKg6ml0O
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  35120e73ff1c18b76979841f426b5654
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.12-KkyYkb9jfDzGqLhKg6ml0O
depends:
    asn1-encoding-0.9.6-2Ju1HaEz5Sj5UyjAXiGMAu
    asn1-types-0.3.4-8wIkxlP65d5JX5x7Ce04W4 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-F8er2OGpWuWCsEVvooYYQh
    crypton-x509-1.7.7-6ZE2kezoXP07qSJKfauo0N directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-FrwZwmFxNiAD2Jd3Lsvkhl
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

